/* --------------------------------------------------------------------------

	(c) 2004-2007 U.S. Robotics Corporation

	-------------------------------------------------------------------------- */


/* --------------------------------------------------------------------------

	SETUP PAGE HEADER

	This outputs the header for a Setup page.
	The passed number indicates which step this is and how many steps there are.

	<img id="idImgHeaderSetup" src="logo.gif">

	If there are three steps, there will be three different headers:

	<div class="idHeader">
		<span class="clsStepDone">Setup</span>
		<span class="clsStepCurrent">1</span>
		<span class="clsStepNotDone">&hellip; 2 &hellip; 3</span>
	</div>

	<div class="idHeader">
		<span class="clsStepDone">Setup 1 &hellip;</span>
		<span class="clsStepCurrent">2</span>
		<span class="clsStepNotDone">&hellip; 3</span>
	</div>

	<div class="idHeader">
		<span class="clsStepDone">Setup 1 &hellip; 2 &hellip;</span>
		<span class="clsStepCurrent">3</span>
	</div>
*/
function writeHeaderSetup(iStep, iSteps)
{
	var strSteps = "<span class=\"clsStepDone\">Setup";
	for (var i = 1; i <= iSteps; ++i)
	{
		if (i == iStep)
			strSteps += "<\/span> <span class=\"clsStepCurrent\">" + i + "<\/span><span class=\"clsStepNotDone\">";
		else
			strSteps += " " + i;

		if (i < iSteps)
			strSteps += " &hellip;";
	}
	strSteps += "<\/span>";

	setPageTitle(document.title);
	_writeHeader(strSteps);
}



/* --------------------------------------------------------------------------

	GENERAL HELPER FUNCTIONS

*/

/*
	This function prompts the user to add a bookmark if the browser's not IE.
	Example:
		<script type="text/javascript">
			document.write('<a href="' + document.location.href + '" title="USRobotics Router" rel="sidebar" onclick="bookmark(this); return false;">Bookmark the router</a>');
		</script>
*/
function bookmark(anchor)
{
	if ((navigator.userAgent.indexOf('MSIE') >= 0) && (navigator.userAgent.indexOf('Opera') < 0))
       window.external.AddFavorite(anchor.getAttribute('href'), anchor.getAttribute('title'));
}


function toggleVisibility(id)
{
	var elt = document.getElementById(id);
	if ((elt == null) || !elt.style || (elt.style.display == null))
		return;

	if (elt.style.display == "none")
		elt.style.display = "";
	else
		elt.style.display = "none";
}


function setVisibility(id, state)
{
	var elt = document.getElementById(id);
	if ((elt == null) || !elt.style || (elt.style.display == null))
		return;

	if (state)
		elt.style.display = "";
	else
		elt.style.display = "none";
}


function setEnabled(id, state)
{
	var elt = document.getElementById(id);
	if ((elt == null) || !elt.style || (elt.style.display == null))
		return;

	elt.disabled = !state;
}



/* --------------------------------------------------------------------------

	FUNCTIONS TO HIDE/SHOW AN HTML TAG WHEN A CHECK BOX IS IN A CERTAIN STATE.

	Example:

	initializePage()
	{
		mapChkToRegions.push(new MapChkToRegion(document.forms[0].chkRelay, "idDHCPrelay", true));
		setRegionVisibility(null);
	}

	HTML:
	<input type="checkbox" name="chkRelay" id="chkRelay" onclick="setRegionVisibility(this);">
*/

function MapChkToRegion(eltChk, idRegion, bVisibleState)
{
	this._eltChk = eltChk;
	this._eltRegion = document.getElementById(idRegion);
	this._bVisibleState = bVisibleState;
}

var mapChkToRegions = new Array();	// of MapChkToRegion objects

/*
	Pass null as the element if you want to set every region.
	Pass an element if you only want to set the visibility of
	the region(s) associated with that element.
*/
function setRegionVisibility(eltChk)
{
	for (var i = 0; i < mapChkToRegions.length; ++i)
	{
		if ((eltChk == null) || (eltChk == mapChkToRegions[i]._eltChk))
		{
			if ((mapChkToRegions[i]._bVisibleState && mapChkToRegions[i]._eltChk.checked) ||
				 (!mapChkToRegions[i]._bVisibleState && !mapChkToRegions[i]._eltChk.checked))
				mapChkToRegions[i]._eltRegion.style.display = "";
			else
				mapChkToRegions[i]._eltRegion.style.display = "none";
		}
	}
}



/* --------------------------------------------------------------------------

	DEVICE FUNCTIONS

*/

/*
	This function validates that the passed string is a valid format for a
	MAC address. The format is six hexadecimal bytes delimited by
	punctuation marks. The hex bytes can be lower or upper case.

	This function returns true if the passed value is a valid MAC format.
	It returns false if it's invalid and displays an error message.

	Valid examples:
		00-AA,BB;CC/DD:EE
		00.aa.bb.cc.dd.ee
*/
function validateMAC(mac)
{
	var re = new RegExp("^[\\dA-F]{2}([:\\.\\-,;/][\\dA-F]{2}){5}$", "i");
	
	if (mac.match(re) == null) {
		alert("Please enter a valid MAC address.\n\nA MAC address is a set of six bytes separated by colons, periods, dashes, commas, semicolons, or slashes. (A byte consists of two hexadecimal digits: 0-9 and A-F.) For example: \"00:C0:49:AA:22:43.\"");
		return false;
	}
	
	return true;
}

/*
	This function converts the MAC address byte delimiters to colons.
*/
function normalizeMAC(mac)
{
	mac = mac.toUpperCase();
	return mac.replace(/\W/g, ":");
}


function validateUsername(elt)
{
	if (elt.value.length == 0)
	{
		alert("Please enter a user name.");
		elt.focus();
		return false;
	}

	return isPrintable("User name", elt);
}

function validatePassword(elt)
{
	if (elt.value.length == 0)
	{
		alert("Please enter a password.");
		elt.focus();
		return false;
	}

	return isPrintable("Password", elt);
}

/*
	This function determines if the passed string contains only printable characters.
	It returns true if the string is okay. It displays an error and returns false
	if the string contains an invalid character.

	95 "printable" characters:
	<space>!"#$%&'()*+,-./:;<=>?@[\]^_`{|}~0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz

	We support ALL "printable" characters in the ASCII and Extended ASCII table.
	These are character codes	32-126, 128-254, inclusive (decimal), or
										0x20-0x7E, 0x80-0xFE, inclusive (hex).
	www.lookuptables.com
*/
function isPrintable(strFieldName, elt)
{
	/*
		Note: We have to escape characters both for Javascript and for RegExp.
				Thus, " must be escaped ONLY for Javascript: \"
						\ and [ and ] must be escaped for RegExp and then the
						escape characters have to be escaped for Javascript:
						\\\\ and \\[ and \\]
	*/
	// Kludge to fix Safari regex bug with Unicode escape sequences
	var re = new RegExp("[^\\x20-\\x7E\\x80-\\xFE]", "g");

	var arMatch = elt.value.match(re);
	// Most browsers return null; Safari returns an empty match object
	if ((arMatch == null) || (arMatch.length == 0))
		return true;

	var strIllegalChars = "";
	for (var i = 0; i < arMatch.length; ++i)	//> This comment is required for some reason.
		strIllegalChars += arMatch[i];

	// There should be some illegal chars at this point, but just in case...
	if (strIllegalChars == "")
		return true;

	// handle KWM Bug
	var strMsg2 = "\n\nPlease use only a-z, A-Z, 0-9, space, punctuation, or charcters in the extended ASCII set, such as accented characters.";
	if (arMatch.length == 1)
		alert("The " + strFieldName + " entry contains an invalid character: " + strIllegalChars + strMsg2);
	else
		alert("The " + strFieldName + " entry contains invalid characters: " + strIllegalChars + strMsg2);

	elt.focus();
	return false;
}



/* --------------------------------------------------------------------------

	WIRELESS SECURITY FUNCTIONS

*/

/*
				ASCII		Hex
	64-bits		 5		10
	128-bits		13		26
	256-bit		29		58

	Arguments:
		bits  the number of bits in the key being generated
		hex	flag indicating if the key is hex
*/
function getKeyLength(bits, bHex)
{
	if (bits == 64)
		return bHex ? 10 : 5;
	else if (bits == 128)
		return bHex ? 26 : 13;
	else // 256
		return bHex ? 58: 29;
}


/*
	Functions to determine key type from the key length
*/

function isKeyASCII(strKey)
{
	var len = strKey.length;
	return ((len == 5) || (len == 13) || (len == 29));
}
function isKeyHex(strKey)
{
	var len = strKey.length;
	return ((len == 10) || (len == 26) || (len == 58));
}


/*
	Returns the number of bits in the passed key.
*/
function getKeySize(strKey)
{
	var len = strKey.length;
	if ((len == 5) || (len == 10))
		return 64;
	if ((len == 13) || (len == 26))
		return 128;
	if ((len == 29) || (len == 58))
		return 256;

	return 0;
}

/*
	Returns true if the passed string is all hex digits.
*/
function isHex(str)
{
    var re = new RegExp("[^A-Fa-f0-9\\d]", "g");
    var arMatch = str.match(re);
    // Most browsers return null; Safari returns an empty match object
    return ((arMatch == null) || (arMatch.length == 0));
}

function validatePassphrase(elt)
{
	if (elt.value.length == 0)
	{
		alert("Please enter a pass phrase.");
		elt.focus();
		return false;
	}
	
	if ((elt.value.length < 8) || (elt.value.length > 63))
	{
		alert("Invalid value for Pass phrase.\n\nThe Pass phrase must be between 8 and 63 characters long.");
		elt.focus();
		return false;
	}

	return isPrintable("Pass phrase", elt);
}

